@@ -10,21 +10,6 @@
 #include "ranfun.h"
 #include "Matrix.h"
 
-//#define IntCal13FNAM "Curves/3Col_intcal13.14C"
-#define IntCal13FNAM "3Col_intcal13.14C"
-#define IntCal13ROWS 5141
-#define IntCal13COLS 3
-
-//#define Marine13FNAM "Curves/3Col_marine13.14C"
-#define Marine13FNAM "3Col_marine13.14C"
-#define Marine13ROWS 4801
-#define Marine13COLS 3
-
-//#define SHCal13FNAM "Curves/3Col_shcal13.14C"
-#define SHCal13FNAM "3Col_shcal13.14C"
-#define SHCal13ROWS 5141
-#define SHCal13COLS 3
-
 //#define IntCal20FNAM "Curves/3Col_intcal20.14C"
 #define IntCal20FNAM "3Col_intcal20.14C"
 #define IntCal20ROWS 9501
@@ -589,7 +574,6 @@ public:
 		if (fcmp(theta, -0.0) == -1) // value < 0 cal BP, postbomb
 		{
 			if (Bomb == 0) {
-				//fprintf( stderr, "WARNING: Calibration attempted beyond IntCal13 cal. curve limits, theta= %f\n",theta);
 				k = 0; //Extrapolation
 				mu = CC(k,1) + (theta-CC(k,0))*(CC(k+1,1)-CC(k,1))/5.0;
 				sig =CC(k,2) + (theta-CC(k,0))*(CC(k+1,2)-CC(k,2))/5.0;
@@ -671,419 +655,6 @@ public:
 	}
 };
 
-
-
-/* IntCal13 */
-class IntCal13 : public Cal {
-
-protected:
-
-	Matrix *CCB;
-	SubMatrix CC;
-	SubMatrix A;
-	int Bomb;
-	Cal *bombcc;
-	char name[255];
-	double mincal, const2;
-
-public:
-
-    IntCal13(int bomb, std::string ccdir) : Cal(IntCal13ROWS) {
-
-		CCB = new Matrix( IntCal13ROWS, IntCal13COLS);
-		CC.Set( CCB, CCB->nRow(), CCB->nCol());
-
-        std::string filename= ccdir+IntCal13FNAM;
-
-        Rprintf("IntCal13: Reading from file: %s\n", filename.c_str());
-
-
-        if (CC.filescan((char*)filename.c_str()) == 0) {
-            REprintf("Cal: ERROR: Could not find IntCal13 cal. curve, file not found: %s\n", filename.c_str());
-            Rcpp::stop("Cal: ERROR: Could not find IntCal13 cal. curve, file not found: %s\n", filename.c_str());
-      //  exit(0);
-    }
-
-		const2 = 0.5*log(2.0 * M_PI); //M_PI defined in gsl library
-
-        const char *postbombfnam[] = { POSTBOMBFNAMS };
-
-		/** Read bomb **/
-		Bomb = bomb;
-		if (Bomb == 0) {
-			mincal = 0.0; // no bomb; 17 Dec 2018 changed -5.0 to 0.0
-			//sprintf( name, "IntCal13");
-			snprintf( name, sizeof(name), "IntCal13");
-		}
-		else
-			if (Bomb < 6) { // curve number, not cal BP yr. 26 March 2019: Was Bomb < 5 but now there are 5 postbomb curves
-
-            bombcc = new GenericCal(postbombfnam[Bomb], ccdir);
-			mincal = bombcc->MinCal();
-			//sprintf( name, "IntCal13+%s", postbombfnam[Bomb]);
-			snprintf( name, sizeof(name), "IntCal13+%s", postbombfnam[Bomb]);
-			}
-			else {
-                REprintf("Bacon: ERROR: Post bomb curve: 0 None, 1 NH1, 2 NH2, 3 NH3, 4 SH1-2, 5 SH3\n");
-                Rcpp::stop("Bacon: ERROR: Post bomb curve: 0 None, 1 NH1, 2 NH2, 3 NH3, 4 SH1-2, 5 SH3\n");
-//				exit(0);
-			}
-
-
-	}
-
-	~IntCal13() {
-		A.~SubMatrix();
-		CC.~SubMatrix();
-		delete CCB;
-	}
-
-
-	double MinCal() { return mincal; }
-	double MaxCal() { return 50000.0; }
-
-    virtual  const char *Name() { return name; } //JEV warning
-
-
-//prototype for gsl_compare
-// x==y, 0, x<y, -1, x>y, 1.
-//int fcmp (double x, double y, double epsilon = 0.00000000001);
-	double cal(double theta)
-	{
-        if (fcmp(theta, -0.0) == -1) // 17 Dec 2018 changed -5.0 to 0.0
-        {
-			if (Bomb == 0) {
-				//fprintf( stderr, "WARNING: Calibration attempted beyond IntCal13 cal. curve limits, theta= %f\n",theta);
-				k = 0; //Extrapolation
-				mu = CC(k,1) + (theta-CC(k,0))*(CC(k+1,1)-CC(k,1))/5.0;
-				sig =CC(k,2) + (theta-CC(k,0))*(CC(k+1,2)-CC(k,2))/5.0;
-			}
-			else {
-				bombcc->cal(theta);
-				mu = bombcc->GetMu();
-				sig = bombcc->GetSig();
-			}
-
-        }
-        else {
-            if (fcmp(theta, 13900.0) != 1)
-                {
-                        k = 0 + (int) floor(theta/5.0); // 0 was 1
-                        mu = CC(k,1) + (theta-CC(k,0))*(CC(k+1,1)-CC(k,1))/5.0;
-                        sig =CC(k,2) + (theta-CC(k,0))*(CC(k+1,2)-CC(k,2))/5.0;
-                }
-                else
-                        if (fcmp(theta, 25000.0) != 1)
-                        {
-                                k = 2780 + (int) floor((theta-13900.0)/10.0); // line 2781 (in c-speak 2780) is 13900 calBP - 10yr steps after this
-                                mu = CC(k,1) + (theta-CC(k,0))*(CC(k+1,1)-CC(k,1))/10.0;
-                                sig = CC(k,2) + (theta-CC(k,0))*(CC(k+1,2)-CC(k,2))/10.0;
-                        }
-                        else
-                                if (fcmp(theta, 50000.0) != 1) // line 3891 (3890 in c-speak) is 25000 cal BP - 20yr steps after this
-                                {
-                                        k = 3890 + (int) floor((theta-25000.0)/20.0);
-                                        mu = CC(k,1) + (theta-CC(k,0))*(CC(k+1,1)-CC(k,1))/20.0;
-                                        sig = CC(k,2) + (theta-CC(k,0))*(CC(k+1,2)-CC(k,2))/20.0;
-                                }
-					else
-						{
-                        //fprintf( stderr, "WARNING: Calibration attempted beyond IntCal13 cal. curve limits, theta= %f\n",theta);
-							k = IntCal13ROWS - 2;
-							mu = CC(k,1) + (theta-CC(k,0))*(CC(k+1,1)-CC(k,1))/100.0;
-							sig = CC(k,2);
-						}
-        }
-            return mu;
-	}
-
-	double U( double y, double vr, double theta)
-	{
-        cal(theta);
-
-        double tau = 1.0/(vr + sqr(sig));
-
-        return const2 - 0.5*log(tau)  + tau * 0.5 * sqr(y-mu);
-	}
-
-	//The new energy using the t distribution
-	double Ut( double y, double vr, double theta, double a, double b)
-	{
-        cal(theta);
-
-        double tau = 1.0/(vr + sqr(sig));
-
-        return (a + 0.5)*log( b + tau * 0.5 * sqr(y-mu));
-	}
-};
-
-
-
-
-
-class Marine13 : public Cal {
-
-protected:
-
-	Matrix *CCB;
-	SubMatrix CC;
-	SubMatrix A;
-	double const2;
-
-public:
-
-    Marine13(std::string ccdir) : Cal(Marine13ROWS) {
-
-		CCB = new Matrix( Marine13ROWS, Marine13COLS);
-
-		CC.Set( CCB, CCB->nRow(), CCB->nCol());
-
-        std::string filename= std::string(ccdir)+std::string(Marine13FNAM);
-
-        Rprintf("Marine13: Reading from file: %s\n", filename.c_str());
-
-        if (CC.filescan((char*)filename.c_str()) == 0) {
-           REprintf("Cal: ERROR: Could not find Marine13 cal. curve, file not found: %s\n", filename.c_str());
-           Rcpp::stop("Cal: ERROR: Could not find Marine13 cal. curve, file not found: %s\n", filename.c_str());
-
-//			exit(0);
-		}
-
-		const2 = 0.5*log(2.0 * M_PI); //M_PI defined in gsl library
-
-
-	}
-
-	~Marine13() {
-		A.~SubMatrix();
-		CC.~SubMatrix();
-		delete CCB;
-	}
-
-
-	double MinCal() { return 0.0; }
-	double MaxCal() { return 50000.0; }
-
-
-	//char *Name() { return "IntCal09Marine"; }
- const char* Name() { return "Marine13"; }
-
-
-//prototype for gsl_compare
-// x==y, 0, x<y, -1, x>y, 1.
-//int fcmp (double x, double y, double epsilon = 0.00000000001);
-	double cal(double theta)
-	{
-        if (fcmp(theta, 0.0) == -1)
-        {
-                //fprintf( stderr, "WARNING: Calibration attempted beyond marine13 cal. curve limits, theta= %f\n",theta);
-                k = 0;
-                mu = CC(k,1) + (theta-CC(k,0))*(CC(k+1,1)-CC(k,1))/5;
-                //sig <- CC(k,2); before JUDY
-                 sig = CC(k,2);
-        }
-        else
-        {       // MB added '{' on 30 Jan 2019 to avoid indentation warning while compiling on Fedora. This '{' was placed correctly for IntCal13 (line 318)
-                if (fcmp(theta, 10500.0) != 1)
-                {       //************** NB: 0 is the number of rows before cal year 0
-                        k = 0 + (int) floor(theta/5.0);
-                        mu = CC(k,1) + (theta-CC(k,0))*(CC(k+1,1)-CC(k,1))/5.0;
-                        sig =CC(k,2) + (theta-CC(k,0))*(CC(k+1,2)-CC(k,2))/5.0;
-                }
-                else
-                        if (fcmp(theta, 25000.0) != 1)
-                        {
-                                k = 2100 + (int) floor((theta-10500.0)/10.0); // steps of 10yr after 10500 (line 2100)
-                                mu = CC(k,1) + (theta-CC(k,0))*(CC(k+1,1)-CC(k,1))/10.0;
-                                sig =CC(k,2) + (theta-CC(k,0))*(CC(k+1,2)-CC(k,2))/10.0;
-                        }
-                        else
-                                if (fcmp(theta, 50000.0) != 1)
-                                {
-                                        k = 3550 + (int) floor((theta-25000.0)/20.0); // steps of 20yr after 25000 (line 3550)
-                                        mu = CC(k,1) + (theta-CC(k,0))*(CC(k+1,1)-CC(k,1))/20.0;
-                                        sig =CC(k,2) + (theta-CC(k,0))*(CC(k+1,2)-CC(k,2))/20.0;
-                                }
-                                else
-                                {
-                        //fprintf( stderr, "WARNING: Calibration attempted beyond IntCal13 cal. curve limits, theta= %f\n",theta);
-                                        k = Marine13ROWS - 2;
-                                        mu = CC(k,1) + (theta-CC(k,0))*(CC(k+1,1)-CC(k,1))/100.0;
-                                        sig =CC(k,2);
-                                }
-        }       // MB added '}' on 30 Jan 2019 to avoid indentation warning while compiling on Fedora
-                return mu;
-        }
-
-
-
-	double U( double y, double vr, double theta)
-	{
-        cal(theta);
-
-        double tau = 1.0/(vr + sqr(sig));
-
-        return const2 - 0.5*log(tau)  + tau * 0.5 * sqr(y-mu);
-	}
-
-
-	//The new energy using the t distribution
-	double Ut( double y, double vr, double theta, double a, double b)
-	{
-        cal(theta);
-
-        double tau = 1.0/(vr + sqr(sig));
-
-        return (a + 0.5)*log( b + tau * 0.5 * sqr(y-mu));
-	}
-
-};
-
-
-
-
-class SHCal13 : public Cal {
-
-protected:
-
-	Matrix *CCB;
-	SubMatrix CC;
-	SubMatrix A;
-	int Bomb;
-	Cal *bombcc;
-	char name[255];
-	double mincal, const2;
-
-public:
-
-    SHCal13(int bomb, std::string ccdir) : Cal(SHCal13ROWS) {
-
-		CCB = new Matrix( SHCal13ROWS, SHCal13COLS);
-		CC.Set( CCB, CCB->nRow(), CCB->nCol());
-        std::string filename= std::string(ccdir)+SHCal13FNAM;
-
-        Rprintf("SHCal13: Reading from file: %s\n", filename.c_str());
-
-            if (CC.filescan((char*)filename.c_str()) == 0) {
-                REprintf("Cal: ERROR: Could not find SHCal13 cal. curve, file not found: %s\n", filename.c_str());
-                Rcpp::stop("Cal: ERROR: Could not find SHCal13 cal. curve, file not found: %s\n", filename.c_str());
-//			exit(0);
-		}
-
-		const2 = 0.5*log(2.0 * M_PI); //M_PI defined in gsl library
-
-        const char * postbombfnam[] = { POSTBOMBFNAMS };
-
-		/** Read bomb **/
-		Bomb = bomb;
-		if (Bomb == 0) {
-			mincal = -0.0; // no bomb, was -5.0 changed 17 Dec 2018
-			//sprintf( name, "SHCal13");
-			snprintf( name, sizeof(name), "SHCal13");
-		}
-		else
-			if (Bomb < 6) { /// was Bomb < 5 but now there are 5 postbomb curves (March 2019)
-
-            bombcc = new GenericCal(postbombfnam[Bomb],(char*)ccdir.c_str());
-			mincal = bombcc->MinCal();
-			//sprintf( name, "SHCal13+%s", postbombfnam[Bomb]);
-			snprintf( name, sizeof(name), "SHCal13+%s", postbombfnam[Bomb]);
-			}
-			else {
-                REprintf("Bacon: ERROR: Post bomb curve: 0 None, 1 NH1, 2 NH2, 3 NH3, 4 SH1-2, 5 SH3\n");
-                Rcpp::stop("Bacon: ERROR: Post bomb curve: 0 None, 1 NH1, 2 NH2, 3 NH3, 4 SH1-2, 5 SH3\n");
-            //	exit(0);
-			}
-
-
-	}
-
-	~SHCal13() {
-		A.~SubMatrix();
-		CC.~SubMatrix();
-		delete CCB;
-	}
-
-
-	double MinCal() { return mincal; }
-	double MaxCal() { return 50000.0; }
-
-    virtual const char *Name() { return name; } //JEV warning
-
-
-//prototype for gsl_compare
-// x==y, 0, x<y, -1, x>y, 1.
-//int fcmp (double x, double y, double epsilon = 0.00000000001);
-	double cal(double theta)
-	{
-        if (fcmp(theta, 0.0) == -1)
-        {
-			if (Bomb == 0) {
-				//fprintf( stderr, "WARNING: Calibration attempted beyond SHCal13 cal. curve limits, theta= %f\n",theta);
-				k = 0; //Extrapolation
-				mu = CC(k,1) + (theta-CC(k,0))*(CC(k+1,1)-CC(k,1))/5.0;
-				sig =CC(k,2) + (theta-CC(k,0))*(CC(k+1,2)-CC(k,2))/5.0;
-			}
-			else {
-				bombcc->cal(theta);
-				mu = bombcc->GetMu();
-				sig = bombcc->GetSig();
-			}
-
-        }
-        else {
-                if (fcmp(theta, 13900.0) != 1)
-                {				//************** NB: In the official SHCal13 year 0 is node 1 (node 0 is -5)
-                        k = 0 + (int) floor(theta/5.0); // 0 was 1
-                        mu = CC(k,1) + (theta-CC(k,0))*(CC(k+1,1)-CC(k,1))/5.0;
-                        sig = CC(k,2) + (theta-CC(k,0))*(CC(k+1,2)-CC(k,2))/5.0;
-                }
-                else
-                        if (fcmp(theta, 25000.0) != 1) // 10yr steps from 13900 on - line 2781 (2780 in c speak)
-                        {
-                                k = 2780 + (int) floor((theta-13900.0)/10.0);
-                                mu = CC(k,1) + (theta-CC(k,0))*(CC(k+1,1)-CC(k,1))/10.0;
-                                sig = CC(k,2) + (theta-CC(k,0))*(CC(k+1,2)-CC(k,2))/10.0;
-                        }
-                        else
-                                if (fcmp(theta, 50000.0) != 1) // 20yr steps from 25000 on - line 3891 (3890 in c speak)
-                                {
-                                        k = 3890 + (int) floor((theta-25000.0)/20.0);
-                                        mu = CC(k,1) + (theta-CC(k,0))*(CC(k+1,1)-CC(k,1))/20.0;
-                                        sig = CC(k,2) + (theta-CC(k,0))*(CC(k+1,2)-CC(k,2))/20.0;
-                                }
-					else
-						{
-                        //fprintf( stderr, "WARNING: Calibration attempted beyond SHCal13 cal. curve limits, theta= %f\n",theta);
-							k = SHCal13ROWS - 2;
-							mu = CC(k,1) + (theta-CC(k,0))*(CC(k+1,1)-CC(k,1))/100.0;
-							sig = CC(k,2);
-						}
-        }
-		return mu;
-	}
-
-	double U( double y, double vr, double theta)
-	{
-        cal(theta);
-
-        double tau = 1.0/(vr + sqr(sig));
-
-        return const2 - 0.5*log(tau)  + tau * 0.5 * sqr(y-mu);
-	}
-
-	//The new energy using the t distribution
-	double Ut( double y, double vr, double theta, double a, double b)
-	{
-        cal(theta);
-
-        double tau = 1.0/(vr + sqr(sig));
-
-        return (a + 0.5)*log( b + tau * 0.5 * sqr(y-mu));
-	}
-};
-
-
 class Plum : public Cal {
 
 	double alPhi, mPhi, alS, mS; //a priori pars form phi and PS
